#!/usr/bin/env python
# -*- coding: utf-8 -*-

from data_dispenser.sources import Source

__author__ = 'Catherine Devlin'
__email__ = 'catherine.devlin@gmail.com'
__version__ = '0.2.0'
